@@ -37,3 +37,10 @@ class Base(Configuration):
             'Authorization': f'Bearer {Configuration.auth_token}',
             'Content-Type': 'application/json'
         }
+
+
+class ZoomException(Exception):
+    """
+    Base Zoom exception
+    """
+    pass
