@@ -1,8 +1,9 @@
 from aiozoom.components.meeting import Meeting
 from aiozoom.components.dashboard import Dashboard
+from aiozoom.components.recording import Recording
 
 
-class Zoom(Meeting, Dashboard):
+class Zoom(Meeting, Dashboard, Recording):
     """
     Main entrypoint for all components
     """
